Welcome to mriqc’s documentation! — mriqc 0.8 documentation

# Welcome to mriqc’s documentation!

# mriqc: image quality metrics for quality assessment of MRI

This pipeline is developed by the Poldrack Lab at Stanford University for use at the Center for Reproducible Neuroscience (CRN), as well as for open-source software distribution.

## About

The package provides a series of image processing workflows to extract and compute a series of NR (no-reference), IQMs (image quality metrics) to be used in QAPs (quality assessment protocols) for MRI (magnetic resonance imaging).

This open-source neuroimaging data processing tool is being developed as a part of the MRI image analysis and reproducibility platform offered by the CRN. This pipeline derives from, and is heavily influenced by, the PCP Quality Assessment Protocol.

This tool extracts a series of IQMs from structural and functional MRI data. It is also scheduled to add diffusion MRI to the target imaging families.

## External Dependencies

`mriqc` is implemented using `nipype`, but it requires some other neuroimaging software tools:

- FSL.
- The N4ITK bias correction tool released with ANTs.
- AFNI.

These tools must be installed and their binaries available in the system’s `$PATH`.

## Installation

The `mriqc` is packaged and available through the PyPi repository. Therefore, the easiest way to install the tool is:

    pip install mriqc

## Execution and the BIDS format

The `mriqc` workflow takes as principal input the path of the dataset that is to be processed. The only requirement to the input dataset is that it has a valid BIDS (Brain Imaging Data Structure) format. This can be easily checked online using the BIDS Validator.

Example command line:

    mriqc -i ~/Data/bids_dataset -o out/ -w work/

## Support and communication

The documentation of this project is found here: http://mriqc.readthedocs.org/en/latest/.

If you have a problem or would like to ask a question about how to use `mriqc`, please submit a question to NeuroStars.org with an `mriqc` tag. NeuroStars.org is a platform similar to StackOverflow but dedicated to neuroinformatics.

All previous `mriqc` questions are available here: http://neurostars.org/t/mriqc/

To participate in the `mriqc` development-related discussions please use the following mailing list: http://mail.python.org/mailman/listinfo/neuroimaging Please add [mriqc] to the subject line when posting on the mailing list.

All bugs, concerns and enhancement requests for this software can be submitted here: https://github.com/poldracklab/mriqc/issues.

## Authors

Oscar Esteban, Krzysztof F. Gorgolewski, Craig A. Moodie, William Triplett. Poldrack Lab, Psychology Department, Stanford University, and Center for Reproducible Neuroscience, Stanford University.

## License information

We use the 3-clause BSD license; the full license is in the file `LICENSE` in the `mriqc` distribution.

All trademarks referenced herein are property of their respective holders.

Copyright (c) 2015-2016, the mriqc developers and the CRN. All rights reserved.

# Contents

- User Guide
- Contents
  - The MRIQC Reports
    - Structural images (sMRI)
    - Functional images (fMRI)
  - mriqc.reports package
    - Submodules
    - mriqc.reports.generators module
    - mriqc.reports.utils module
    - Module contents
  - Installation
  - Dependencies
  - Running mriqc
- MRIQC measures
  - Structural images (sMRI)
  - Functional images (fMRI)
  - References
- Run mriqc with docker
  - Preliminaries
  - Running mriqc
  - Explaining the mriqc-docker command line

# Indices and tables

- Index
- Module Index
- Search Page